#!/bin/bash

# ==============================================================================
# Configuration
# ==============================================================================

minversion="10.4.1"
CWROOT="/usr/local/curbywall"
BIN="/usr/sbin"
DMNROOT="/Library/LaunchDaemons"
CONFROOT="/etc"
execfiles=( "curbywall" "ipfw-status" )
inertfiles=( "ipfw.conf" "local.conf.sample" "routing.conf.sample" "shaping.conf.sample" "README" "COPYING" )



# ==============================================================================
# Sanity Checks
# ==============================================================================

# Check platform
if [[ "`sw_vers -productVersion`" < $minversion ]]; then
  echo "This firewall makes use of features new in OS X $minversion.  If you think you know better,"
  echo "disable this check or install the files manually."
  exit 1
fi

# Check permissions
if [[ "$UID" != "0" ]]; then
  echo "You need to have root privileges to run this script."
  echo "You might try running 'sudo $0'."
  exit 2
fi



# ==============================================================================
# Uninstall old version
# ==============================================================================

if [[ -e "$CWROOT/install.log" ]]; then
  echo "Old version found.  Uninstalling... "
  while IFS= read -r file; do
    if [[ -d "$file" ]]; then
      rmdir -p "$file"
    elif [[ -h "$file" || -e "$file" ]]; then
      rm "$file"
    fi
  done < "$CWROOT/install.log"
fi



# ==============================================================================
# Install current version
# ==============================================================================

# Make curbywall directory
echo "Making $CWROOT directory..."
install -d -m 755 -g wheel "$CWROOT"

# Install executables and their symlinks
echo -n "Installing files... "
for file in "${execfiles[@]}"; do
  echo -n "$file, "
  install -m 755 -g wheel "$file" "$CWROOT"
  echo "$CWROOT/$file" >> "$CWROOT/install.log"
  echo -n "$BIN/$file, "
  ln -s "$CWROOT/$file" "$BIN/$file"
  echo "$BIN/$file" >> "$CWROOT/install.log"
done

# Install non-executables
for file in "${inertfiles[@]}"; do
  echo -n "$file, "
  install -m 644 -g wheel "$file" "$CWROOT"
  echo "$CWROOT/$file" >> "$CWROOT/install.log"
done

# Install sysctl file
echo -n "$CONFROOT/sysctl.conf, "
install -m 644 -g wheel "sysctl.conf" "$CONFROOT"
echo "$CONFROOT/sysctl.conf" >> "$CWROOT/install.log"

# Install LaunchDaemon
echo "$DMNROOT/net.curby.Curbywall.plist"
install -m 644 -g wheel "net.curby.Curbywall.plist" "$DMNROOT"
echo "$DMNROOT/net.curby.Curbywall.plist" >> "$CWROOT/install.log"

# Remember to uninstall the uninstall log and our directory
echo "$CWROOT/install.log" >> "$CWROOT/install.log"
echo "$CWROOT" >> "$CWROOT/install.log"

# Enable logging both for reboots and now
echo "Enabling verbose logging..."
defaults write "/Library/Preferences/com.apple.sharing.firewall" loggingenabled -integer '1'
sysctl -w net.inet.ip.fw.verbose=2 > /dev/null

echo "Installation completed.  Run curbywall to initialize firewall."
